import styled, { css, keyframes } from 'styled-components';

const scrollDown = keyframes`
  0% {
    opacity: 0;
    transform: translateY(0) rotate(-45deg);
  }
  30% {
    opacity: 1;
    transform: translateY(10px) rotate(-45deg);
  }
  60% {
    opacity: 1;
    transform: translateY(5px) rotate(-45deg);
  }
  100% {
    top: 90%;
    opacity: 0;
    transform: translateY(0) rotate(-45deg);
  }
`

export const Button = styled.button<{
  size: number;
  secondary?: boolean;
}>`
  position: relative;
  width: ${({ size }) => `${size}px`};
  height: ${({ size }) => `${size}px`};
  border: none;
  border-radius: 50%;
  z-index: 10;

  cursor: pointer;
  
  &:after {
    content: '';
    display: block;
    width: 20%;
    height: 20%;
    border: 2px solid;
    margin: auto;
  }

  ${({ secondary, theme }) =>
    !secondary
      ? css`
          background: ${theme.colors.button.activePrimaryButton};

          &:after {
            margin-top: 14%;
            border-color: transparent transparent
              ${theme.colors.button.buttonTypography} ${theme.colors.button.buttonTypography};
            transform: rotate(135deg);
          }

          &:hover {
            background: ${theme.colors.button.hoverPrimaryButton};
          }
        `
      : css`
          background: transparent;
          border: none;
          

          &:after {
            margin-bottom: 26%;
            border-color: transparent transparent
              ${theme.colors.button.activeSecondaryButton}
              ${theme.colors.button.activeSecondaryButton};
              transform: translateY(0) rotate(-45deg);
            animation: ${scrollDown} 1s ease-in-out infinite;
          }
          &:before {
            content: '';
            display: block;
            width: 20%;
            height: 20%;
            border: 2px solid;
            margin: auto;
            margin-bottom: -8%;
            border-color: transparent transparent
              ${theme.colors.button.activeSecondaryButton}
              ${theme.colors.button.activeSecondaryButton};
            transform: rotate(-45deg);
            animation: ${scrollDown} 1s ease-in-out infinite;
            animation-delay: 0.05s;

          }

          &:hover {
            &:after, &:before {
              border-color: transparent transparent
                ${theme.colors.button.hoverSecondaryButton}
                ${theme.colors.button.hoverSecondaryButton};
            }
          }
        `}
`;