import { FC, HTMLAttributes, useEffect, useRef, useState } from 'react';
import useEventListener from './hooks/useEventListener';
import { Content, Ripple, StyledButton } from './styled'

export interface Props extends HTMLAttributes<HTMLButtonElement>{
    /**
        * This is the size of the font.
    */
    size?: number;
    /**
        * This is the font-weight of the font.
    */
    weight?: number;
    /**
        * This is the width of the button.
    */
    width?: number;
    /**
        * This is a boolean attribute that swaps between primary and secondary button.
    */
    secondary?: boolean;
    /**
        * This is a boolean attribute that toggles between active or inactive button.
    */
    disabled?: boolean;
}

export const Button: FC<Props> = ({ children, ...args }) => {
    const ButtonRef = useRef<HTMLButtonElement>(null);
    const [coords, setCoords] = useState({ x: -1, y: -1 });
    const [isRippling, setIsRippling] = useState(false);
    
    useEffect(() => {
        if (coords.x !== -1 && coords.y !== -1) {
            setIsRippling(true);
            setTimeout(() => setIsRippling(false), 300);
        } else setIsRippling(false);
    }, [coords]);
    
    useEffect(() => {
        if (!isRippling) setCoords({ x: -1, y: -1 });
    }, [isRippling]);

    const handleOnClick = (event: any) => {
        const rect = event.target.getBoundingClientRect();
        setCoords({ x: event.clientX - rect.left, y: event.clientY - rect.top });
    };

    useEventListener('click', handleOnClick, ButtonRef);

    return (
        <StyledButton ref={ButtonRef} {...args}>
            {isRippling ? (
                <Ripple {...args} style={{ left: coords.x, top: coords.y }} />
            ) : (
                ''
            )}
            <Content>{children}</Content>
        </StyledButton>
    )
}
export default Button;