import styled, { css, keyframes } from 'styled-components';

export const RippleEffect = keyframes`
  0% {
    transform: scale(1);
    opacity: 1;
  }
  50% {
    transform: scale(10);
    opacity: 0.375;
  }
  100% {
    transform: scale(35);
    opacity: 0;
  }
`

export const StyledButton = styled.button<{
  size?: number;
  weight?: number;
  width?: number;
  secondary?: boolean;
  disabled?: boolean;
}>`
  position: relative;
  width: 100%;
  max-width: 343px;
  margin: 9px 0;
  border: none;
  border-radius: 30px;

  position: relative;
  overflow: hidden;

  font-family: ${({ theme }) => theme.fonts.primary};
  font-size: ${({ size }) => (size ? `${size}px` : '20px')};
  font-weight: ${({ weight }) => weight || 700};
  cursor: pointer;

  @media screen and (min-width: 768px) {
    width: ${({ width }) => (width ? `${width}%` : 'auto')};
    max-width: none;
    padding: 15px 50px;
  }

  ${({ secondary, disabled, theme }) =>
    !secondary &&
    !disabled &&
    css`
      padding: 15px 0;
      background: ${theme.colors.button.activePrimaryButton};
      color: ${theme.colors.button.buttonTypography};
      &:hover {
        background: ${theme.colors.button.hoverPrimaryButton};
      }
    `}
  ${({ secondary, disabled, theme }) =>
    secondary &&
    !disabled &&
    css`
      padding: 14px 0;
      border: 2px solid;
      background: ${theme.colors.background.primaryBackgroundColor};
      color: ${theme.colors.button.activeSecondaryButton};
      &:hover {
        color: ${theme.colors.button.hoverSecondaryButton};
      }

      @media screen and (min-width: 768px) {
        padding: 13px 48px;
      } 
    `}
  ${({ secondary, disabled, theme }) =>
    !secondary &&
    disabled &&
    css`
      padding: 15px 0;
      background: ${theme.colors.typography.disabled};
      color: ${theme.colors.typography.disabledTypography};
    `}
  ${({ secondary, disabled, theme }) =>
    secondary &&
    disabled &&
    css`
      padding: 14px 0;
      border: 2px solid;
      background: ${theme.colors.background.primaryBackgroundColor};
      color: ${theme.colors.typography.disabled};
    `}
`;

export const Ripple = styled.span<{secondary?: boolean}>`
  width: 20px;
  height: 20px;
  position: absolute;
  background-color: ${({ theme }) => theme.colors.button.clickPrimaryButton};
  display: block;
  content: "";
  border-radius: 9999px;
  opacity: 1;
  animation: 0.9s ease forwards ${RippleEffect};

  ${({ secondary, theme }) =>
    secondary &&
    css`
      background-color: ${theme.colors.button.clickSecondaryButton};
    `}
`

export const Content = styled.span`
  position: relative;
  z-index: 2;
`