import styled, { css } from 'styled-components';
import successIcon from '../assets/is-success.svg';
import errorIcon from '../assets/is-error.svg';
import search from '../assets/search.svg';

export const StyledInput = styled.input<{
  placeholderSize?: string;
  error?: string;
  success?: string;
  secondary?: boolean;
}>`
  width: 100%;
  height: 45px;
  padding-left: ${({ placeholderSize }) =>
    placeholderSize ? '9.5px' : '20px'};
  padding-right: ${({ placeholderSize }) =>
    placeholderSize ? '9.5px' : '20px'};

  border: 1px solid;
  border-color: ${({ theme }) => theme.colors.inputs.disabled};
  border-radius: 100px;
  outline: none;

  font-size: 16px;
  font-weight: 500;
  line-height: 19px;
  font-family: ${({ theme }) => theme.fonts.primary};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};
  background-color: ${({ theme }) => theme.colors.background.backgroundCard};

  background-repeat: no-repeat;
  background-position: 96% center;

  ${({ theme, error, success }) =>
    error &&
    !success &&
    css`
      padding-right: 36px;
      border-color: ${theme.colors.inputs.error}};
      background-image: url(${errorIcon});
    `}

  ${({ theme, error, success }) =>
    !error &&
    success &&
    css`
      padding-right: 36px;
      border-color: ${theme.colors.inputs.success};
      background-image: url(${successIcon});
    `}

    ${({ theme, secondary }) =>
    secondary &&
    css`
      background-color: ${({ theme }) => theme.colors.background.backgroundForm};
      box-shadow: ${theme.boxShadow.shadowCards};
      border: none;
    `}

    ${({ type }) =>
    type === 'search' &&
    css`
      padding-left: 58px;
      background-color: ${({ theme }) => theme.colors.background.backgroundForm};
      background-image: url(${search});
      background-position: 6% center;
      @media screen and (min-width: 768px) {
        background-position: 2% center;
      }
    `}

  ${({ type, error }) =>
    type === 'search' &&
    error &&
    css`
      padding-left: 58px;
      background-image: url(${search}), url(${errorIcon});
      background-position: 6% center, 96% center;
    `}

  &::placeholder {
    font-size: ${({ placeholderSize }) =>
      placeholderSize ? `${placeholderSize}px` : '16px'};
    font-weight: 300;
    line-height: 14px;
    color: ${({ theme }) => theme.colors.inputs.disabledTypography};
  }

  &:focus {
    border-color: ${({ theme }) => theme.colors.inputs.focus};
  }

  @media screen and (min-width: 768px) {
    height: 52px;

    &::placeholder {
      font-size: 16px;
    }
  }
`;

export const InputMessage = styled.p<{ type: 'error' | 'success' }>`
  margin-top: 10px;
  padding-left: 20px;
  color: ${({ theme, type }) =>
    type === 'error' ? theme.colors.inputs.error : theme.colors.inputs.success};
  font-family: ${({ theme }) => theme.fonts.primary};
`;
