/* eslint-disable react/require-default-props */
import { FC, useState, InputHTMLAttributes, useRef, Dispatch, SetStateAction, useEffect } from 'react';
import { useOnClickOutside } from '../hooks/useOnClickOutside';
import { InputMessage } from './styled';
import {
  StyledInput,
  InputContainer,
  SelectDefaultOption,
  OptionsList,
  FlagButton,
  Flag,
  OptionButton,
  Option,
  OptionCountry,
  OptionPrefix
} from './styled';

export interface Countries {
  name: string
  dialCode: string
  isoCode: string
  flag: string
}

export interface Props extends InputHTMLAttributes<HTMLInputElement> {
  error?: string;
  success?: string;
  countries: Countries[]
  getPrefix?: Dispatch<SetStateAction<string>>
  onChangeValue: (val: string) => void
}

export const InputPhone: FC<Props> = ({ error, success, countries, getPrefix, onChangeValue, ...props }) => {
  const [isActive, setIsActive] = useState<boolean>(false);
  const [phone, setPhone] = useState<string>('');
  const inputRef = useRef<HTMLElement>(null);
  const onlyNumbers = /^[0-9]+$/;

  useOnClickOutside(inputRef,() => setIsActive(false));

  const [{ prefix, isFlag, country }, setPrefix] = useState({
    prefix: '+54',
    isFlag: 'https://cdn.kcak11.com/CountryFlags/countries/ar.svg',
    country: 'Argentina'
  });

  const activeToggle = () => setIsActive(!isActive);

  const handleClick = (name: string, dialCode: string, flag: string) => {
    setPrefix({ country: name, prefix: dialCode, isFlag: flag });
    setIsActive(!isActive);
  };

  const handleOnlyNumbers = (val: string) => {
    if (val.length > 0) {
        if (!onlyNumbers.test(val.at(-1)!)) return
    }
    setPhone( val );
  }

  useEffect(() => getPrefix && getPrefix(prefix), [prefix]);

  useEffect(() => {
    onChangeValue(prefix + phone);
  }, [prefix, phone]);

  return (
    <>
      <InputContainer isActive={isActive} ref={inputRef}>
        <StyledInput
          {...props}
          value={phone}
          onChange={ (e) => handleOnlyNumbers(e.target.value)}
          error={!!error}
          success={!!success}
          isActive={isActive}
        />
        <SelectDefaultOption isActive={isActive}>
          <FlagButton type='button' onClick={activeToggle} isActive={isActive}>
            <Flag src={isFlag} alt={country} />
          </FlagButton>
          <span>{prefix}</span>
        </SelectDefaultOption>

        <OptionsList isActive={isActive}>
          {countries.map(({ name, dialCode, flag }) => (
            <Option key={name}>
              <OptionButton
                type='button'
                onClick={() => handleClick(name, dialCode, flag)}
              >
                <Flag src={flag} alt={name} />
                <OptionCountry>{name}</OptionCountry>
                <OptionPrefix>({dialCode})</OptionPrefix>
              </OptionButton>
            </Option>
          ))}
        </OptionsList>
      </InputContainer>
      {!!error && <InputMessage type='error'>{error}</InputMessage>}
      {!!success && <InputMessage type='success'>{success}</InputMessage>}
    </>
  );
};

export default InputPhone;