import styled, { css } from 'styled-components';
import successIcon from '../assets/is-success.svg';
import errorIcon from '../assets/is-error.svg';

export const InputContainer = styled.section<{ isActive: boolean }>`
  position: relative;
  font-size: 16px;
  line-height: 19px;
  font-family: ${({ theme }) => theme.fonts.primary};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};

  &:after {
    content: '';
    position: absolute;
    top: 51px;
    left: 25px;
    display: block;
    width: 86%;
    ${({ theme, isActive }) =>
      isActive && `border-top: 1px solid ${theme.colors.inputs.disabled}`};
  }

  @media screen and (min-width: 768px) {
    font-size: 18px;
    line-height: 21px;

    &::after {
      width: 90%;
    }
  }
`;

export const StyledInput = styled.input<{
  isActive: boolean;
  error: boolean;
  success: boolean;
}>`
  display: block;
  width: 100%;
  padding: 12px 36px 12px 118px;
  padding-bottom: ${({ isActive }) => isActive && '178px'};
  border: 1px solid ${({ theme }) => theme.colors.inputs.disabled};
  border-color: ${({ isActive }) => isActive && 'transparent'};
  border-radius: 30px;
  outline: none;

  font-size: inherit;
  font-family: inherit;
  color: inherit;

  background-color: transparent;
  background-repeat: no-repeat;
  background-position: 96% 10px;

  box-shadow: ${({ theme, isActive }) =>
    isActive && theme.boxShadow.shadowCards};

  transition: border-color 0.3s ease, box-shadow 0.3s ease-in-out,
    padding-bottom 0.3s ease-in-out;

  ${({ theme, error, success }) =>
    error &&
    !success &&
    css`
      border-color: ${theme.colors.inputs.error};
      background-image: url(${errorIcon});
    `}
  ${({ theme, error, success }) =>
    !error &&
    success &&
    css`
      border-color: ${theme.colors.inputs.success};
      background-image: url(${successIcon});
    `}

  &::placeholder {
    text-align: start;
    font-weight: 300;
  }

  &:focus {
    border-color: ${({ theme, isActive }) =>
      !isActive && theme.colors.inputs.focus};
  }

  @media screen and (min-width: 768px) {
    padding: 14px 44px 14px 122px;
    padding-bottom: ${({ isActive }) => isActive && '186px'};
    background-position-y: 12px;
  }
`;

export const SelectDefaultOption = styled.article<{ isActive: boolean }>`
  position: absolute;
  top: 1px;
  left: 1px;
  display: flex;
  justify-content: space-between;
  align-items: center;
  width: 111px;
  padding: 8px 6px 8px 20px;

  border-radius: 30px;
  color: inherit;

  & span {
    padding-top: 4px;
    padding-bottom: 4px;
  }

  @media screen and (min-width: 768px) {
    padding-top: 10px;
    padding-bottom: 10px;
  }
`;

export const FlagButton = styled.button<{ isActive: boolean }>`
  display: flex;
  padding-top: 4px;
  padding-bottom: 4px;
  border: none;
  border-right: 1px solid ${({ theme }) => theme.colors.inputs.disabled};
  background: none;
  cursor: pointer;

  &:after {
    content: '';
    display: block;
    margin-top: 3px;
    margin-right: 8.5px;
    border-left: 5px solid transparent;
    border-right: 5px solid transparent;
    border-top: 7px solid
      ${({ theme }) => theme.colors.typography.primaryTypography};

    transform: ${({ isActive }) =>
      isActive ? 'rotate(-180deg)' : 'rotate(0)'};

    transition: transform 0.3s ease-in-out;

    @media screen and (min-width: 768px) {
      margin-right: 6px;
    }
  }
  @media screen and (min-width: 768px) {
    padding-top: 6px;
    padding-bottom: 6px;
  }
`;

export const Flag = styled.img`
  width: 21px;
  height: 13px;
  margin-right: 8px;
  border-radius: 3px;

  @media screen and (min-width: 768px) {
    margin-right: 5px;
  }
`;

export const OptionsList = styled.ul<{ isActive: boolean }>`
  position: absolute;
  top: 54px;
  left: 23px;
  width: 85%;
  height: ${({ isActive }) => (isActive ? '130px' : '0')};
  margin-top: ${({ isActive }) => (isActive ? '14px' : '0')};
  margin-bottom: 24px;

  list-style: none;
  overflow: auto;
  &::-webkit-scrollbar{
      width: 8px;
  }

  &::-webkit-scrollbar-track {
      background: ${({ theme }) =>
        theme.colors.background.backgroundNavSwitcher};
  }

  &::-webkit-scrollbar-thumb {
      background-color: ${({ theme }) =>
        theme.colors.underline.primaryUnderline};
      border-radius: 30px;

      &:hover, &:active {
          background-color: #97E2DF;
      }
  }

  transition: height 0.3s ease-in-out, margin-top 0.3s ease-in-out;

  @media screen and (min-width: 768px) {
    width: 91%;
  }
`;

export const Option = styled.li`
  margin-bottom: 15px;
`;

export const OptionButton = styled.button`
  border: none;
  font-size: inherit;
  font-weight: 300;
  font-family: inherit;
  color: inherit;
  background: none;
  cursor: pointer;
`;

export const OptionCountry = styled.span`
  margin-left: 4px;
`;
export const OptionPrefix = styled.span`
  margin-left: 6px;
  color: ${({ theme }) => theme.colors.inputs.disabled};
`;

export const InputMessage = styled.p<{ type: 'error' | 'success' }>`
  margin-top: 10px;
  padding-left: 20px;
  color: ${({ theme, type }) =>
    type === 'error' ? theme.colors.inputs.error : theme.colors.inputs.success};
  font-family: ${({ theme }) => theme.fonts.primary};
`;
