/* eslint-disable react/require-default-props */
import { FC, useRef, useState } from 'react';
import useElementSize from '../hooks/useElementSize';
import { useOnClickOutside } from '../hooks/useOnClickOutside';
import {
  SelectContainer,
  SelectDefaultOption,
  OptionsContainer,
  Option,
  InputMessage,
  Container
} from './styled';

export interface Props {
  error?: string;
  success?: string;
  secondary?: boolean;
  name: string;
  placeholder: string;
  categories: string[];
  onOptionChange: (val: string) => void;
}

export const SelectList: FC<Props> = ({
  error,
  success,
  secondary,
  name,
  placeholder,
  categories,
  onOptionChange
}) => {
  const [squareRef, { width }] = useElementSize();
  const inputRef = useRef<HTMLElement>(null);
  const [option, setOption] = useState<string>(
    placeholder || 'Select category'
  );
  const [isActive, setIsActive] = useState<boolean>(false);

  useOnClickOutside(inputRef,() => setIsActive(false));

  const handleisActive = () => setIsActive(!isActive);

  const handleOption = (category: string) => {
    setOption(category);
    onOptionChange(category);
    handleisActive();
  };

  return (
    <>
      <Container ref={squareRef}>
        <SelectContainer
          ref={inputRef}
          isActive={isActive}
          error={error!}
          success={success!}
          secondary={secondary!}
        >
          <SelectDefaultOption
            name={name}
            type='button'
            onClick={handleisActive}
            isActive={isActive}
          >
            {option}
          </SelectDefaultOption>
          <OptionsContainer isActive={isActive} width={width}>
            {categories ? (
              categories.map((category) => (
                <li key={category}>
                  <Option type='button' onClick={() => handleOption(category)}>
                    {category}
                  </Option>
                </li>
              ))
            ) : (
              <p>Cargando...</p>
            )}
          </OptionsContainer>
        </SelectContainer>
      </Container>
      {!!error && <InputMessage type='error'>{error}</InputMessage>}
      {!!success && <InputMessage type='success'>{success}</InputMessage>}
    </>
  );
};
export default SelectList;