import styled, { css } from 'styled-components';

export const Container = styled.section`
  width: 100%;
`;

export const SelectContainer = styled.section<{
  isActive: boolean;
  error: string;
  success: string;
  secondary: boolean;
}>`
  position: relative;
  z-index: 6;
  border-radius: ${({ isActive }) => (isActive ? '30px 30px 0 0' : '30px')};
  //
  width: 100%;
  padding: 11.5px 23px;
  border: 1px solid
    ${({ theme, isActive }) =>
      !isActive ? theme.colors.inputs.disabled : 'transparent'};

  font-family: ${({ theme }) => theme.fonts.primary};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};

  background-color: ${({ theme }) => theme.colors.background.backgroundCard};
  box-shadow: ${({ theme, isActive }) =>
    isActive && theme.boxShadow.shadowCards};

  transition: border 0.3s ease, box-shadow 0.3s ease-in-out, border-radius 0.3s ease-in-out;


  &:focus {
    border-color: ${({ theme, isActive }) =>
      !isActive && theme.colors.inputs.focus};
  }

  @media screen and (min-width: 768px) {
    padding: 16.5px 23px;
  }

  ${({ theme, error, success }) =>
    error &&
    !success &&
    css`
      padding-right: 36px;
      border-color: ${theme.colors.inputs.error}};
    `}

  ${({ theme, error, success }) =>
    !error &&
    success &&
    css`
      padding-right: 36px;
      border-color: ${theme.colors.inputs.success};
    `}

    ${({ theme, secondary }) =>
    secondary &&
    css`
      box-shadow: ${theme.boxShadow.shadowCards};
      border: none;
    `}
`;

export const SelectDefaultOption = styled.button<{ isActive: boolean }>`
  position: relative;
  text-align: start;
  width: 100%;
  border: none;

  font-size: 16px;
  font-weight: 500;
  font-family: inherit;
  line-height: 19px;
  color: inherit;

  background: none;
  cursor: pointer;

  &:after {
    content: '';
    position: absolute;
    top: 0;
    right: 0;
    width: 10px;
    height: 10px;
    border: 2px solid;
    border-color: ${({ theme }) =>
      `transparent transparent ${theme.colors.underline.primaryUnderline} ${theme.colors.underline.primaryUnderline}`};

    transform: ${({ isActive }) =>
      isActive ? 'rotate(-225deg) translateX(10px)' : 'rotate(-45deg)'};

    transition: transform 0.3s ease-in-out;
  }
`;

export const OptionsContainer = styled.ul<{ isActive: boolean, width: number }>`
  position: absolute;
  background-color: ${({ theme, isActive }) => isActive? theme.colors.background.backgroundCard : 'transparent'};
  width: ${({ width }) => `${width}px`};
  box-shadow: ${({ theme }) => theme.boxShadow.shadowCards};
  border-radius: 0 0 30px 30px;
  padding: 0 20px;
  z-index: 5;
  transform: translate(-24px);
  //
  height: ${({ isActive }) => (isActive ? '133px' : '0')};
  margin-top: ${({ isActive }) => (isActive ? '14px' : '0')};
  border-top: 1px solid
    ${({ theme, isActive }) =>
      isActive ? theme.colors.typography.disabled : 'transparent'};

  list-style: none;
  overflow: auto;

  transition: height 0.3s ease-in-out, margin-top 0.3s ease-in-out,
    border-top-color 0.5s ease, background-color 0.3s ease-in-out;
  
  &::-webkit-scrollbar {
    display: none;
  }

  & li {
    margin-bottom: 19px;

    &:first-child {
      margin-top: 18px;
    }
  }
`;

export const Option = styled.button`
  border: none;
  font-family: inherit;
  color: inherit;
  background: none;
  cursor: pointer;
`;

export const InputMessage = styled.p<{ type: 'error' | 'success' }>`
  margin-top: 10px;
  padding-left: 20px;
  color: ${({ theme, type }) =>
    type === 'error' ? theme.colors.inputs.error : theme.colors.inputs.success};
  font-family: ${({ theme }) => theme.fonts.primary};
`;
