import { FC, useRef, useState, useEffect, ChangeEvent } from 'react';
import useElementSize from '../hooks/useElementSize';
import { useOnClickOutside } from '../hooks/useOnClickOutside';

import {
  SelectContainer,
  SelectButton,
  OptionsContainer,
  Label,
  CheckBox,
  InputMessage,
  Container
} from './styled';

export interface Props {
  categories: string[];
  placeholder: string;
  name: string;
  error?: string;
  success?: string;
  onOptionChange: (val: object) => void;
}

export const SelectListWCheckbox: FC<Props> = ({
  categories,
  placeholder,
  name,
  error,
  success,
  onOptionChange
}) => {
  const [squareRef, { width }] = useElementSize();
  const inputRef = useRef<HTMLElement>(null);
  const [isActive, setIsActive] = useState<boolean>(false);
  const [options, setOptions] = useState<object>({});

  const handleisActive = (): void => setIsActive(!isActive);

  useOnClickOutside(inputRef, () => setIsActive(false));

  const handleOption = (e: ChangeEvent<HTMLInputElement>, category: string) => {
    Object.keys(options).map(
      (key) =>
        key === category &&
        setOptions((prev) => ({ ...prev, [category]: e.target.checked }))
    );
  };

  useEffect(() => {
    categories.map((category) =>
      setOptions((prev) => ({ ...prev, [category]: false }))
    );
  }, [categories]);

  useEffect(() => {
    onOptionChange(options);
  }, [options]);

  return (
    <>
      <Container ref={squareRef}>
        <SelectContainer isActive={isActive} ref={inputRef}>
          <SelectButton
            name={name}
            type='button'
            onClick={handleisActive}
            isActive={isActive}
          >
            {placeholder || 'Select category'}
          </SelectButton>
          <OptionsContainer isActive={isActive} width={width}>
            {categories ? (
              categories.map((category) => (
                <li key={category}>
                  <CheckBox
                    name={category}
                    id={category}
                    type='checkbox'
                    onChange={(e) => handleOption(e, category)}
                  />
                  <Label htmlFor={category}>{category}</Label>
                </li>
              ))
            ) : (
              <p>Cargando...</p>
            )}
          </OptionsContainer>
        </SelectContainer>
      </Container>
      {!!error && <InputMessage type='error'>{error}</InputMessage>}
      {!!success && <InputMessage type='success'>{success}</InputMessage>}
    </>
  );
};

export default SelectListWCheckbox;
