import styled, { css } from 'styled-components';

export const Container = styled.section`
  width: 100%;
`;

export const SelectContainer = styled.section<{ isActive: boolean }>`
  position: relative;
  z-index: 6;
  border-radius: ${({ isActive }) => (isActive ? '30px 30px 0 0' : '30px')};
  //
  width: 100%;
  padding: 12.5px 20px;

  font-size: 16px;
  font-weight: 500;
  line-height: 19px;
  font-family: ${({ theme }) => theme.fonts.secondary};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};

  background-color: ${({ theme }) => theme.colors.background.backgroundForm};
  box-shadow: ${({ theme }) => theme.boxShadow.shadowCards};
  transition: border-radius 0.3s ease-in-out;

  @media screen and (min-width: 768px) {
    padding: 16.5px 20px;
  }
`;

export const SelectButton = styled.button<{ isActive: boolean }>`
  position: relative;
  text-align: start;
  width: 100%;
  border: none;

  font-size: inherit;
  font-weight: inherit;
  font-family: inherit;
  line-height: inherit;
  color: inherit;

  background: none;
  cursor: pointer;

  &:after {
    content: '';
    position: absolute;
    top: 2px;
    right: 0;
    width: 10px;
    height: 10px;
    border: 2px solid;
    border-color: ${({ theme }) =>
      `transparent transparent ${theme.colors.underline.primaryUnderline} ${theme.colors.underline.primaryUnderline}`};

    transform: ${({ isActive }) =>
      isActive ? 'rotate(-225deg) translateX(10px)' : 'rotate(-45deg)'};

    transition: transform 0.3s ease-in-out;
  }
`;

export const OptionsContainer = styled.ul<{ isActive: boolean; width: number }>`
  position: absolute;
  background-color: ${({ theme, isActive }) => isActive? theme.colors.background.backgroundForm : 'transparent'};
  width: ${({ width }) => `${width}px`};
  box-shadow: ${({ theme }) => theme.boxShadow.shadowCards};
  border-radius: 0 0 30px 30px;
  padding: 0 20px;
  z-index: 5;
  transform: translate(-20px);
  //
  height: ${({ isActive }) => (isActive ? '140px' : '0')};
  margin-top: ${({ isActive }) => (isActive ? '13px' : '0')};
  border-top: 1px solid
    ${({ theme, isActive }) =>
      isActive ? theme.colors.typography.disabled : 'transparent'};

  list-style: none;
  overflow: auto;

  transition: height 0.3s ease-in-out, margin-top 0.3s ease-in-out,
    border-top-color 0.5s ease, background-color 0.3s ease-in-out;

  &::-webkit-scrollbar {
    display: none;
  }

  & li {
    margin-top: 23px;

    &:first-child {
      margin-top: 18.5px;
    }
  }

  @media screen and (min-width: 768px) {
    height: ${({ isActive }) => (isActive ? '146px' : '0')};
    margin-top: ${({ isActive }) => (isActive ? '16px' : '0')};

    & li {
      margin-top: 19px;

      &:first-child {
        margin-top: 27px;
      }
    }
  }
`;

export const Label = styled.label`
  position: relative;
  padding-left: 30px;
  cursor: pointer;

  &::before {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    width: 16px;
    height: 16px;
    border: 1px solid ${({ theme }) => theme.colors.underline.primaryUnderline};
    border-radius: 2px;
    background: transparent;
  }
`;

export const CheckBox = styled.input`
  display: none;

  &:checked + ${Label}::after {
    content: '';
    position: absolute;
    top: 5px;
    left: 5px;
    width: 6px;
    height: 4px;

    border: 1px solid;
    border-color: ${({ theme }) =>
      `transparent transparent ${theme.colors.underline.primaryUnderline} ${theme.colors.underline.primaryUnderline}`};
    transform: rotate(-55deg);
  }
`;

export const InputMessage = styled.p<{ type: 'error' | 'success' }>`
  margin-top: 10px;
  padding-left: 20px;
  color: ${({ theme, type }) =>
    type === 'error' ? theme.colors.inputs.error : theme.colors.inputs.success};
  font-family: ${({ theme }) => theme.fonts.primary};
`;
