import styled, { css } from 'styled-components';
import successIcon from '../assets/is-success.svg';
import errorIcon from '../assets/is-error.svg';

export const StyledTextArea = styled.textarea<{
  error?: string;
  success?: string;
}>`
  width: 100%;
  padding: 13px 11% 13px 20px;
  border: 1px solid;
  border-radius: 30px;
  outline: none;

  font-family: ${({ theme }) => theme.fonts.primary};
  font-size: 16px;
  color: ${({ theme }) => theme.colors.typography.primaryTypography};

  background-color: ${({ theme }) => theme.colors.background.backgroundCard};
  background-repeat: no-repeat;
  background-position: 96% center;
  resize: none;

  ${({ theme, error, success }) =>
    !error && !success && `border-color: ${theme.colors.inputs.disabled}};`}
  ${({ theme, error, success }) =>
    error &&
    !success &&
    css`
      border-color: ${theme.colors.inputs.error}};
      background-image: url(${errorIcon});
    `}
  ${({ theme, error, success }) =>
    !error &&
    success &&
    css`
      border-color: ${theme.colors.inputs.success};
      background-image: url(${successIcon});
    `}

  &::placeholder {
    font-weight: 300;
    color: ${({ theme }) => theme.colors.inputs.disabledTypography};
  }

  &:focus {
    border-color: ${({ theme }) => theme.colors.inputs.focus};
  }
`;

export const InputMessage = styled.p<{ type: 'error' | 'success' }>`
  margin-top: 10px;
  padding-left: 20px;
  color: ${({ theme, type }) =>
    type === 'error' ? theme.colors.inputs.error : theme.colors.inputs.success};
  font-family: ${({ theme }) => theme.fonts.primary};
`;