/* eslint-disable react/require-default-props */
import { FC } from 'react';
import {
  FacebookIcon,
  TwitterIcon,
  InstagramIcon,
  LinkedinIcon,
  TelegramIcon,
  TiktokIcon,
  TwitchIcon,
  YoutubeIcon,
  PinterestIcon,
  GithubIcon,
  BehanceIcon,
  WebIcon
} from '../../svgc/socialNetworkIcons';
import { Icon } from './styled';
import WhatsappIcon from '../../svgc/socialNetworkIcons/WhatsappIcon';

export enum SocialNetwork {
  facebook = 'facebook',
  twitter = 'twitter',
  instagram = 'instagram',
  linkedin = 'linkedin',
  telegram = 'telegram',
  tiktok = 'tiktok',
  twitch = 'twitch',
  youtube = 'youtube',
  pinterest = 'pinterest',
  github = 'github',
  behance = 'behance',
  web = 'web',
  whatsapp = 'whatsapp'
}

export interface Props extends React.AnchorHTMLAttributes<HTMLAnchorElement> {
  socialNetwork: SocialNetwork | string;
  to?: string;
  size: number;
}

export const SocialNetworkButton: FC<Props> = ({ socialNetwork, to, size }) => {
  let linkIcon;
  let imgIcon;
  switch (socialNetwork) {
    case SocialNetwork.facebook:
      linkIcon = 'https://www.facebook.com/';
      imgIcon = <FacebookIcon width={size} />;
      break;
    case SocialNetwork.twitter:
      linkIcon = 'https://twitter.com/?lang=es';
      imgIcon = <TwitterIcon width={size} />;
      break;
    case SocialNetwork.instagram:
      linkIcon = 'https://www.instagram.com/?hl=es';
      imgIcon = <InstagramIcon width={size} />;
      break;
    case SocialNetwork.linkedin:
      linkIcon = 'https://www.linkedin.com/feed/';
      imgIcon = <LinkedinIcon width={size} />;
      break;
    case SocialNetwork.telegram:
      linkIcon = 'https://web.telegram.org/k/';
      imgIcon = <TelegramIcon width={size} />;
      break;
    case SocialNetwork.tiktok:
      linkIcon = 'https://www.tiktok.com/es/';
      imgIcon = <TiktokIcon width={size} />;
      break;
    case SocialNetwork.twitch:
      linkIcon = 'https://www.twitch.tv/';
      imgIcon = <TwitchIcon width={size} />;
      break;
    case SocialNetwork.youtube:
      linkIcon = 'https://www.youtube.com/';
      imgIcon = <YoutubeIcon width={size} />;
      break;
    case SocialNetwork.pinterest:
        linkIcon = 'https://www.pinterest.com/';
        imgIcon = <PinterestIcon width={size} />;
        break;
    case SocialNetwork.github:
      linkIcon = 'https://www.github.com/';
      imgIcon = <GithubIcon width={size} />;
      break;
    case SocialNetwork.behance:
      linkIcon = 'https://www.behance.com/';
      imgIcon = <BehanceIcon width={size} />;
      break;
    case SocialNetwork.web:
      linkIcon = 'https://www.upwaydigitalsolutions.com/';
      imgIcon = <WebIcon width={size} />;
      break;
    case SocialNetwork.whatsapp:
        linkIcon = 'https://api.whatsapp.com/message/D5VO36UTZADWJ1?autoload=1&app_absent=0';
        imgIcon = <WhatsappIcon width={size} />;
        break;

    default:
      linkIcon = '';
      imgIcon = <FacebookIcon width={0} />;
      break;
  }
  return (
    <a href={to || linkIcon} aria-label="Link" target='_blank' rel='noreferrer'>
      <Icon>{imgIcon}</Icon>
    </a>
  );
};

export default SocialNetworkButton;