import styled from 'styled-components';

export const CardContainer = styled.article`
  width: 100%;
  padding: 12px 33px 8px;
  border-radius: 40px;

  background-color: ${({ theme }) => theme.colors.background.backgroundCard};
  box-shadow: ${({ theme }) => theme.boxShadow.shadowCards};
`;

export const List = styled.ul`
  list-style: none;

  li {
    border-bottom: 1px solid ${({ theme }) => theme.colors.typography.alphaTypography};
    &:last-child {
      border-bottom: none;
    }
  }
`;

export const ContainerQuestion = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 20px 0 17.5px;
  cursor: pointer;

  @media screen and (min-width: 768px) {
    padding-bottom: 27px;
  }
`;

export const Question = styled.h3`
  font-size: 18px;
  line-height: 21px;
  font-weight: 600;
  font-family: ${({ theme }) => theme.fonts.secondary};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};
  cursor: pointer;

  @media screen and (min-width: 768px) {
    font-size: 28px;
    line-height: 33px;
  }
`;

export const ButtonQuestion = styled.button<{ isOpen: boolean }>`
  border: none;
  background-color: transparent;
  transform: rotate(${({ isOpen }) => (isOpen ? '0' : '180deg')});
  transition: transform 0.3s ease-in-out;
  cursor: pointer;

  & span svg {
    width: 30px;
    path {
      stroke: ${({ theme }) => theme.colors.button.activeTertiaryLink};
    }
  }

  @media screen and (min-width: 768px) {
    /* padding: 19px 8px 26px 31px; */
  }
`;

export const Answer = styled.p<{ isOpen: boolean }>`
  max-height: ${({ isOpen }) => (isOpen ? '300px' : '0')};
  margin-bottom: ${({ isOpen }) => (isOpen ? '30px' : '0')};
  font-family: ${({ theme }) => (theme.fonts.primary)};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};
  overflow: hidden;
  transition: max-height 0.5s ease-in-out, margin-bottom 0.5s ease-in-out;
`;
