import { FC } from 'react';
import { CalendarIcon, ClockIcon } from '../../svgc/';
import { SocialNetworkButton } from '../../atoms';
import { SocialNetwork } from '../../atoms/socialNetworkButton/SocialNetworkButton';
import {
  CardContainer,
  Img,
  CardBody,
  Title,
  TimeContainer,
  Time,
  Content,
  ContainerButtons,
  Share,
  BlogButton
} from './styled';

export interface Props extends React.HTMLAttributes<HTMLElement> {
  title: string;
  date: string;
  howLong: string;
  content: string;
  img: string;
  imgOnClick: React.MouseEventHandler<HTMLImageElement> | undefined;
  btnValue: string;
  btnOnClick: React.MouseEventHandler<HTMLButtonElement> | undefined;
}

export const MadiumBlogCard: FC<Props> = ({
  img,
  title,
  date,
  howLong,
  content,
  imgOnClick,
  btnValue,
  btnOnClick,
  ...props
}) => (
  <CardContainer { ...props }>
    <Img src={img} alt={title} onClick={ imgOnClick } />
    <CardBody>
      <Title>{title}</Title>
      <TimeContainer>
        <Time>
          <CalendarIcon width={20} />
          <time>{date}</time>
        </Time>
        <Time>
          <ClockIcon width={22} />
          <time>{howLong}</time>
        </Time>
      </TimeContainer>
      <Content>{content}</Content>
      <ContainerButtons>
        <BlogButton secondary weight={500} onClick={ btnOnClick }>
          { btnValue }
        </BlogButton>
        <Share>
          <SocialNetworkButton socialNetwork={SocialNetwork.twitter} size={42} />
          <SocialNetworkButton socialNetwork={SocialNetwork.facebook} size={42} />
          <SocialNetworkButton
            socialNetwork={SocialNetwork.instagram}
            size={42}
          />
          <SocialNetworkButton socialNetwork={SocialNetwork.linkedin} size={42} />
        </Share>
      </ContainerButtons>
    </CardBody>
  </CardContainer>
);

export default MadiumBlogCard;