import { FC, MouseEventHandler } from 'react';
import {
  CardContainer,
  Title,
  Position,
  Location,
  OtherVacanciesButton,
  CenterButton
} from './styled';

export interface Props extends React.HTMLAttributes<HTMLElement> {
  title?: string;
  otherVacancies: { id: string; position: string; location: string }[];
  btnValue?: string;
  btnOnClick: MouseEventHandler<HTMLButtonElement> | undefined;
}

export const OtherVacanciesCard: FC<Props> = ({ title, otherVacancies, btnValue, btnOnClick, ...props }) => (
  <CardContainer { ...props }>
    <Title>{ title || 'Otras vacantes' }</Title>
    {otherVacancies.map(({ id, position, location }) => (
      <div key={id}>
        <Position>{position}</Position>
        <Location>{location}</Location>
      </div>
    ))}
    <CenterButton>
      <OtherVacanciesButton secondary weight={500} size={18} onClick={btnOnClick}>
        { btnValue || 'Ver todas' }
      </OtherVacanciesButton>
    </CenterButton>
  </CardContainer>
);

export default OtherVacanciesCard;