/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable react/require-default-props */
import { FC, MouseEventHandler, useState, useRef } from 'react';
import { TickWithText } from '../../atoms';
import { InfoIcon } from '../../svgc';
import {
  CardContainer,
  CardDetail,
  Price,
  PayContainer,
  Pay,
  TitleList,
  List,
  Item,
  ServicesButton
} from './styled';
import { useOnClickOutside } from './helpers/useOnClickOutside';

export interface Props {
  plan: string;
  price: string;
  advise: string;
  quoteAdvise?: string;
  includeTitle?: string;
  include: string[];
  button: string;
  btnOnClick?: MouseEventHandler<HTMLButtonElement> | undefined;
}

export const ServicesCard: FC<Props> = ({
  plan,
  price,
  advise,
  quoteAdvise,
  includeTitle,
  include,
  button,
  btnOnClick
}) => {
  const [tooltipIsActive, setTooltipIsActive] = useState<boolean>(false);
  const toolTip = useRef(null);
  const handleTooltipIsActive = () => setTooltipIsActive(!tooltipIsActive);
  useOnClickOutside(toolTip, () => setTooltipIsActive(false));

  return (
    <CardContainer plan={plan}>
      <CardDetail>
        <Price>{price}</Price>
        <PayContainer quoteAdvise={quoteAdvise} isActive={tooltipIsActive}>
          <div ref={toolTip} onClick={() => handleTooltipIsActive()}>
            <InfoIcon />
          </div>
          <Pay>{advise}</Pay>
        </PayContainer>
        <TitleList>{includeTitle}</TitleList>
        <List>
          {include.map((detail) => (
            <Item key={detail}>
              <TickWithText text={detail} fontSize={14} />
            </Item>
          ))}
        </List>
        <ServicesButton secondary weight={500} size={22} onClick={btnOnClick}>
          {button}
        </ServicesButton>
      </CardDetail>
    </CardContainer>
  );
};

export default ServicesCard;