import styled, { css } from 'styled-components';
import { Button } from '../../atoms/';

export const CardContainer = styled.article<{plan:string}>`
  width: 100%;
  max-width: 393px;
  border-radius: 40px;
  padding: 30px 0 0;
  height: 100%;
  position: relative;

  font-size: 18px;
  font-weight: 500;
  line-height: 21px;
  box-shadow: ${({ theme }) => theme.boxShadow.shadowCards};

  &:before {
    content: '${({ plan }) => plan}';
    position: absolute;
    text-align: center;
    height: 80px;
    width: 100%;
    max-width: 393px;
    border-radius: 40px 40px 0 0;
    transform: translateY(-30px);
    padding-top: 8px;

    font-size: 18px;
    font-weight: 500;
    line-height: 21px;
    font-family: ${({ theme }) => theme.fonts.primary};
    color: ${({ theme }) => theme.colors.button.buttonTypography};
    box-shadow: ${({ theme }) => theme.boxShadow.shadowCards};
    background: ${({ theme }) => theme.colors.gradient.gradient};
    z-index: -1;
  }
`;

export const CardDetail = styled.div`
  text-align: start;
  border-radius: 40px;
  margin-top: 8px;
  padding: 45px 40px 20px;

  background-color: ${({ theme }) => theme.colors.background.backgroundCard};
`;

export const Price = styled.h3`
  margin-bottom: 6px;
  font-size: 40px;
  font-weight: 700;
  line-height: 47px;
  font-family: ${({ theme }) => theme.fonts.primary};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};
`;

export const PayContainer = styled.div<{
  quoteAdvise?: string;
  isActive: boolean;
}>`
  display: flex;
  align-items: center;
  margin-bottom: 48px;
  font-family: ${({ theme }) => theme.fonts.primary};

  ${({ isActive, quoteAdvise }) =>
    isActive &&
    css`
      div:before {
      content: '${quoteAdvise}';
      font-size: 12px;
      max-width: 300px;
      position: absolute;
      height: auto;
      width: auto;
      transform: translate(-30px, 28px);
      background: ${({ theme }) => theme.colors.background.backgroundNavSwitcher};
      color: ${({ theme }) => theme.colors.typography.primaryTypography};
      border-radius: 40px;
      padding: 16px 30px;
      opacity: 0.95;
      box-shadow: ${({ theme }) => theme.boxShadow.shadowNav};
    }
    :after {
      content: '';
      position: absolute;
      border-style: solid;
      border-width: 0 8px 8px 8px;
      border-color: transparent transparent
        ${({ theme }) => theme.colors.background.backgroundNavSwitcher} transparent;
      opacity: 0.9;
      transform: translate(-2px, 14px);
    }
  }
    `}
  svg {
    cursor: pointer;
  }
  & svg path {
    fill: ${({ theme }) => theme.colors.typography.filterTypography};
  }
`;

export const Pay = styled.span`
  margin-left: 4px;
  font-size: 14px;
  font-weight: 400;
  line-height: 16px;
  color: ${({ theme }) => theme.colors.typography.filterTypography};
`;

export const TitleList = styled.h4`
  margin-bottom: 13px;
  font-size: 16px;
  font-weight: 500;
  line-height: 19px;
  font-family: ${({ theme }) => theme.fonts.primary};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};
  
  @media screen and (min-width: 768px) {
    height: 32px;
    margin-bottom: 0px;
  }
`;

export const List = styled.ul`
  margin-bottom: 47px;
  list-style: none;
`;

export const Item = styled.li`
  margin-bottom: 4.5px;
`;

export const ServicesButton = styled(Button)`
  padding: 7px;
  @media screen and (min-width: 768px) {
    width: 100%;
  }
`;
