/* eslint-disable react/require-default-props */
import { FC, MouseEventHandler } from 'react';
import {
  CardContainer,
  Img,
  CardBody,
  Title,
  TimeContainer,
  Time,
  Content,
  Tag
} from './styled';
import { CalendarIcon, ClockIcon } from '../../svgc/'

export interface Props extends React.HTMLAttributes<HTMLElement>{
  title: string;
  date: string;
  howLong: string;
  content: string;
  tags: string[];
  img?: string;
  imgOnClick?: MouseEventHandler<HTMLImageElement> | undefined;
}

export const SmallBlogCard: FC<Props> = ({
  img,
  title,
  date,
  howLong,
  content,
  tags,
  imgOnClick,
  ...props
}) => (
  <CardContainer { ...props }>
    <Img
      src={img || './assets/blog/blog-img.svg'}
      alt={title}
      onClick={imgOnClick}
    />
    <CardBody>
      <Title>{title}</Title>
      <TimeContainer>
        <Time>
          <CalendarIcon />
          <time>{date}</time>
        </Time>
        <Time>
          <ClockIcon />
          <time>{howLong}</time>
        </Time>
      </TimeContainer>

      <Content>{content}</Content>
      {
        tags.map((tag) => (
          <Tag key={tag}>{`#${tag}`}</Tag>
        ))
      }
    </CardBody>
  </CardContainer>
);

export default SmallBlogCard;