import { FC } from 'react';
import { SocialNetworkButton } from '../../atoms/socialNetworkButton/SocialNetworkButton';
import { CardContainer, Img, Title, Content, Social } from './styled';

export interface Socials {
  name: string;
  to: string;
  size?: number;
}

export interface Props extends React.HTMLAttributes<HTMLElement> {
  rol: string;
  image: string;
  name: string;
  profession: string;
  social: Socials[];
}

export const TeamCard: FC<Props> = ({
  rol,
  image,
  name,
  profession,
  social,
  ...props
}) => (
  <CardContainer rol={rol} {...props}>
    <Img src={image} alt={name} />
    <Title>{name}</Title>
    <Content>{profession}</Content>
    <Social>
      {social.map((socials) => (
        <SocialNetworkButton
          key={socials.name}
          socialNetwork={socials.name}
          to={socials.to}
          size={socials.size || 45}
        />
      ))}
    </Social>
  </CardContainer>
);

export default TeamCard;