import styled from 'styled-components';

export const CardContainer = styled.article<{ quotes?: string }>`
  position: relative;
  width: 100%;
  max-width: 417px;
  height: auto;
  padding: 26px 42px;
  border-radius: 40px;

  background-color: ${({ theme }) => theme.colors.background.backgroundCard};
  box-shadow: ${({ theme }) => theme.boxShadow.shadowCards};

  &::before {
    content: ${({ quotes }) => quotes ? `url(${quotes})` : 'url(./assets/testimonials/quotes.svg)'};
    position: absolute;
    top: -24px;
    right: 34px;
  }

  @media screen and (min-width: 768px) {
    padding: 50px 40px 38px 40px;
  }
`;

export const Img = styled.img`
  display: block;
  width: 52px;
  margin: 0 auto 15px;
  border-radius: 50%;

  @media screen and (min-width: 768px) {
    width: 70px;
    margin-bottom: 21px;
  }
`;

export const Title = styled.h3`
  text-align: center;
  margin-bottom: 1px;
  font-size: 18px;
  font-weight: 700;
  color: ${({ theme }) => theme.colors.typography.primaryTypography};
  font-family: ${({ theme }) => theme.fonts.primary};

  @media screen and (min-width: 768px) {
    margin-bottom: 10px;
  }
`;

export const Stars = styled.div`
  text-align: center;
  margin-bottom: 24px
  svg {
    margin-top: 4px;
    width: 16px;
  }

  @media screen and (min-width: 768px) {
    width: 18;
    margin-bottom: 30px;
    & svg {
      width: 20px;
    }
  }
`;

export const Blockquote = styled.blockquote`
  padding-bottom: 20px;
  font-size: 14px;
  font-weight: 400;
  line-height: 24px;
  font-family: ${({ theme }) => theme.fonts.primary};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};
`;
