import { FC, useEffect, useState } from 'react';
import { UnderlineButton } from '../../atoms/';
import { ButtonContainer } from './styled'

export interface Props extends React.HTMLAttributes<HTMLDivElement> {
    titles: string[];
    setWhoIsActive?: React.Dispatch<React.SetStateAction<string>>;
}

export const UnderlineFilter: FC<Props> = ({ titles, setWhoIsActive, ...props }) => {
    const [isActiveButton, setIsActiveButton] = useState<string>(titles[0] || '');

    const handleSetIsActiveButton = (title: string) => isActiveButton !== title && setIsActiveButton(title);

    useEffect(() => setWhoIsActive && setWhoIsActive(isActiveButton), [isActiveButton])

    return (
        <ButtonContainer { ...props }>
            {titles.map((title) => (
                <UnderlineButton key={title} onClick={() => handleSetIsActiveButton(title)}
                    isActive={title === isActiveButton}>
                    {title}
                </UnderlineButton>
            ))}
        </ButtonContainer>
    )
}

export default UnderlineFilter;