/* eslint-disable react/require-default-props */
import { FC, HTMLAttributes, MouseEventHandler } from 'react';
import { CardContainer, Title, Paragraph, VacanciesButton } from './styled';

export interface Props extends HTMLAttributes<HTMLDivElement>{
  title: string;
  positionKey: string;
  positionValue: string;
  locationKey: string;
  locationValue: string;
  btnValue: string;
  btnOnClick?: MouseEventHandler<HTMLButtonElement> | undefined;
}

export const VacancyCard: FC<Props> = ({
  title,
  positionKey,
  positionValue,
  locationKey,
  locationValue,
  btnValue,
  btnOnClick,
  ...args
}) => (
  <CardContainer { ...args } >
    <Title>{title}</Title>
    <Paragraph>
      {positionKey || 'Position'}: <span>{positionValue}</span>
    </Paragraph>
    <Paragraph>
      {locationKey || 'Location'}: <span>{locationValue}</span>
    </Paragraph>
    <VacanciesButton secondary width={100} weight={500} onClick={btnOnClick}>
      {btnValue || 'Postularme'}
    </VacanciesButton>
  </CardContainer>
);

export default VacancyCard;