import { FC, useState } from 'react';
import { TickWithText } from '../../atoms';
import {
  Title,
  CardContainer,
  TitleContainer,
  ListValuesAndVision,
  ListMission
} from './styled';

export interface Props {
  data: Data[];
}

export interface Data {
  name: string;
  content: string[];
}

export const VVMCard: FC<Props> = ({ data }) => {
  const [isActiveFilter, setIsActiveFilter] = useState<string>(
    data[0].name || ''
  );
  const handleClick = (title: string) => {
    if (isActiveFilter !== title) setIsActiveFilter(title);
  };

  return (
    <CardContainer>
      <TitleContainer>
        {data.map(({ name }) => (
          <Title
            key={name}
            onClick={() => handleClick(name)}
            active={isActiveFilter === name}
          >
            {name}
          </Title>
        ))}
      </TitleContainer>

      {data.map(
        ({ name, content }) =>
          name === isActiveFilter &&
          (data[data.length - 1]?.name !== isActiveFilter ? (
            <ListValuesAndVision key={name}>
              {content.map((Item) => (
                <li key={Item}>
                  <TickWithText text={Item} fontSize={16} />
                </li>
              ))}
            </ListValuesAndVision>
          ) : (
            <ListMission key={name}>
              {content.map((Item) => (
                <li key={Item}>
                  <p>{Item}</p>
                </li>
              ))}
            </ListMission>
          ))
      )}
    </CardContainer>
  );
};

export default VVMCard;