import styled from 'styled-components';

export const CardContainer = styled.article`
  width: 100%;
  max-width: 589px;
  border-radius: 40px;

  font-family: ${({ theme }) => theme.fonts.primary};
  color: ${({ theme }) => theme.colors.typography.primaryTypography};

  background-color: ${({ theme }) => theme.colors.background.secondaryBackgroundColor};
  box-shadow: ${({ theme }) => theme.title === 'LIGHT' ? '0px 4px 20px 0px #0025541A' : '0px 4px 20px 0px #FFFFFF26' };
  overflow: hidden;
`;

export const TitleContainer = styled.div`
  display: flex;
  padding-top: 18px;
  padding-bottom: 13px;
  box-shadow: ${({ theme }) => theme.boxShadow.shadowCards};
  background-color: ${({ theme }) => theme.colors.background.backgroundCard};
`;

export const Title = styled.button<{ active: boolean }>`
  position: relative;
  text-align: center;
  width: 33%;
  padding-left: 10px;

  font-family: ${({ theme }) => theme.fonts.secondary};
  font-weight: 700;
  font-size: 16px;
  line-height: 24px;
  color: ${({ active, theme }) =>
    active ? theme.colors.button.hoverPrimaryButton : theme.colors.typography.primaryTypography};

  background: none;
  border: none;
  cursor: pointer;

  &::after {
    content: '';
    position: absolute;
    left: 50%;
    bottom: -30px;
    transform: translateX(-50%);
    border-left: 12px solid transparent;
    border-right: 12px solid transparent;
    border-top: 28px solid
      ${({ active, theme }) =>
        active ? theme.colors.background.backgroundCard : 'transparent'};
  }

  &:nth-child(2) {
    border-left: 1px solid ${({ theme }) => theme.colors.background.backgroundNavSwitcher};
    border-right: 1px solid ${({ theme }) => theme.colors.background.backgroundNavSwitcher};
  }

  @media screen and (min-width: 768px) {
    font-size: 20px;
    line-height: 30px;

    &::after {
      bottom: -34px;
    }
  }
`;

export const ListValuesAndVision = styled.ul`
  padding: 29px 40px;
  list-style: none;
  font-size: 16px;
  font-weight: 400;
  line-height: 27.5px;

  & li span svg {
    width: 22px;
  }

  @media screen and (min-width: 768px) {
    padding: 48px 40px 58px;
    line-height: 18.3px;

    & li span svg {
      width: 26.5px;
    }
  }
`;

export const ListMission = styled.ul`
  padding: 29px 40px;
  list-style: none;

  & p {
    margin-bottom: 20px;
    font-size: 16px;
    font-weight: 400;
    line-height: 25px;
  }

  @media screen and (min-width: 768px) {
    padding-top: 48px;
    line-height: 18.3px;
  }
`;
