import { ComponentStory, ComponentMeta } from '@storybook/react';
import { Button } from '../../core/atoms/button/Button';


export default {
    title: 'Atoms/Button',
    component: Button,
    argTypes: {
        size: { 
            control: 'number' , defaultValue: 20, type: { name: 'number', required: false },
            table: { defaultValue: { summary: 20 } },
            description: 'This is the size of the font.'
        },
        weight: { 
            control: 'number', defaultValue: 700, type: { name: 'number', required: false },
            table: { defaultValue: { summary: 700 } },
            description: 'This is the font-weight of the font.'
        },
        width: { 
            control: 'number', required: false, type: { name: 'number', required: false },
            table: { defaultValue: { summary: '< 768px: 100% | >= 768px: auto' } },
            description: 'This is the width of the button.'
        },
        secondary: { 
            control: 'boolean', defaultValue: false, type: { name: 'boolean', required: false },
            table: { defaultValue: { summary: false } },
            description: 'This is a boolean attribute that swaps between primary and secondary button.'
        },
        disabled: { 
            control: 'boolean', defaultValue: false, type: { name: 'boolean', required: false },
            table: { defaultValue: { summary: false } },
            description: 'This is a boolean attribute that toggles between active or inactive button.'
        }
    },
} as ComponentMeta<typeof Button>;

const Template: ComponentStory<typeof Button> = (args) => <Button {...args}>I am a Button</Button>;

export const Primary = Template.bind({});
Primary.args = {
    size: 25
};

export const Secondary = Template.bind({});
Secondary.args = {
    size: 25,
    secondary: true
};

export const Disabled = Template.bind({});
Disabled.args = {
    size: 25,
    disabled: true
};

export const AllProps = Template.bind({});
AllProps.args = {
    size: 25,
    weight: 700,
    width: 100,
    secondary: true,
    disabled: true
};
