import { ComponentStory, ComponentMeta } from '@storybook/react';
import { MadiumBlogCard } from '../../core/molecules';
import blog from '../assets/big-blog.svg';

export default {
    title: 'Molecules/MadiumBlogCard',
    component: MadiumBlogCard,
    argTypes: {
        title: { 
            control: 'text', type: { name: 'string', required: true },
            table: { defaultValue: { summary: 'string' } },
            description: 'This is the title in the card.'
        },
        date: { 
            description: 'Blog creation date.'
        },
        howLong: { 
            description: 'Reading time.'
        },
        content: { 
            description: 'Content summary.'
        },
        img: { 
            description: 'Blog image.'
        },
        btnValue: {
            description: 'Blog button value.'
        },
        imgOnClick: { 
            action: () => alert('Image onClick Event'),
            table: { defaultValue: { summary: '() => void' } },
            description: 'This is the image onClick event handler in the card.'
        },
        btnOnClick: { 
            action: () => alert('Button onClick Event'),
            table: { defaultValue: { summary: '() => void' } },
            description: 'This is the button onClick event handler in the card.'
        },
    },
} as ComponentMeta<typeof MadiumBlogCard>;

const Template: ComponentStory<typeof MadiumBlogCard> = (args) => <MadiumBlogCard {...args}/>;

export const Primary = Template.bind({});
Primary.args = {
    title: 'Titulo Principal (destacado semanal)',
    date: '12 Dic. 2021',
    howLong: '12 mins',
    content: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Amet, id sed nunc, dignissim vel nec luctus. Magna tristique adipiscing mauris, ut fermentum. Duis nunc enim ut egestas at lectus amet non. Vitae justo dolor eu felis mattis tincidunt sem dignissim. Porttitor elementum suspendisse eget aliquet feugiat diam placerat id. Purus quis aenean quam pellentesque posuere interdum. Adipiscing lectus et non arcu. Felis nunc purus nulla arcu varius sagittis. Sit etiam egestas .',
    img: blog,
    btnValue: 'Seguir leyendo',
    imgOnClick: () => alert('Image Event'),
    btnOnClick: () => alert('Button Event')
};